(fabric-using)=
# Using the eFPGA

This contains information on how to run and configure the RTL-to-bitstream flow for a FABulous fabric. It mainly consists of the steps place and route, synthesis and building he actual binary bitstream from a FASM file.

```{toctree}
synthesis/index
pnr/index
bitstream/bitstream_generation
```
